pub struct GetValueResponse {
pub key: String,
pub value: Primitive,
}Fields
key: Stringvalue: PrimitiveTrait Implementations
Sourceimpl Clone for GetValueResponse
impl Clone for GetValueResponse
Sourcefn clone(&self) -> GetValueResponse
fn clone(&self) -> GetValueResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GetValueResponse
impl Debug for GetValueResponse
Sourceimpl<'de> Deserialize<'de> for GetValueResponse
impl<'de> Deserialize<'de> for GetValueResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for GetValueResponse
impl JsonSchema for GetValueResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for GetValueResponse
impl PartialEq for GetValueResponse
Sourceimpl Serialize for GetValueResponse
impl Serialize for GetValueResponse
impl StructuralPartialEq for GetValueResponse